@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::StaticInstall; # git description: v0.007-3-g2f4477f
+package Dist::Zilla::Plugin::StaticInstall; # git description: v0.008-8-gdac440b
 # ABSTRACT: (EXPERIMENTAL, DANGEROUS) Identify a distribution as eligible for static installation
 # KEYWORDS: distribution metadata toolchain static dynamic installation
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
@@ -16,6 +16,8 @@ use MooseX::Types::Moose qw(Str Bool);
 use Scalar::Util 'blessed';
 use List::Util 1.33 qw(first any);
 no autovivification;
+use Term::ANSIColor 3.00 'colored';
+use Path::Tiny;
 use namespace::autoclean;
 
 my $mode_type = enum([qw(off on auto)]);
@@ -39,6 +41,7 @@ around dump_config => sub
     $config->{+__PACKAGE__} = {
         mode => $self->mode,
         dry_run => $self->dry_run ? 1 : 0,
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
     return $config;
@@ -92,7 +95,7 @@ sub setup_installer
     $self->${ \ ($self->dry_run ? 'log' : 'log_debug') }($message) if $message;
 
     # say what we would do, if dry run or heuristic different than requested
-    $self->log([ 'would set x_static_install to %s', $value ])
+    $self->log([ colored('would set x_static_install to %s', 'yellow'), $value ])
         if $self->dry_run or ($value and $self->mode eq 'off');
 
     if (not exists $distmeta->{x_static_install} and $self->mode eq 'auto' and not $self->dry_run)
@@ -126,6 +129,31 @@ sub _heuristics
             @build_requires > 1 ? 's' : '',
             join(', ', sort @build_requires) ]) if @build_requires;
 
+    $self->$log('checking execdirs');
+    if (my @execfiles_plugins = @{ $self->zilla->plugins_with(-ExecFiles) })
+    {
+        my @bad_unempty_execdirs =
+            map { m{^([^/]+)/}g }
+            grep { path($_) !~ m{^script/} }
+            map { $_->name }
+            map {; @{ $_->find_files } }
+            @execfiles_plugins;
+
+        return (0, [ 'found ineligible executable dir%s \'%s\'',
+                (@bad_unempty_execdirs == 1 ? '' : 's'), join(', ', @bad_unempty_execdirs) ])
+            if @bad_unempty_execdirs;
+
+        if (my @bad_execdirs =
+                grep { $_ ne 'script' }
+                map { $_->dir }
+                grep { $_->isa('Dist::Zilla::Plugin::ExecDir') }
+                @execfiles_plugins)
+        {
+            $self->log([ colored('found ineligible executable dir%s \'%s\' configured: better to avoid', 'yellow'),
+                (@bad_execdirs == 1 ? '' : 's'), join(', ', @bad_execdirs) ]);
+        }
+    }
+
     $self->$log('checking sharedirs');
     my @module_sharedirs = keys %{ $self->zilla->_share_dir_map->{module} };
     return (0, [ 'found module sharedir%s for %s',
@@ -204,7 +232,7 @@ Dist::Zilla::Plugin::StaticInstall - (EXPERIMENTAL, DANGEROUS) Identify a distri
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -240,7 +268,10 @@ are not involved in this testing. The proper installation of the built
 distribution cannot be guaranteed if installed with a static install-enabled
 client.
 
-The current preconditions for C<x_static_install> being true include:
+The tentative specification is spelled out in more detail in
+L<https://github.com/Leont/cpan-static/blob/master/lib/CPAN/Static/Spec.pm>.
+
+This plugin currently checks these conditions (if all are true, C<x_static_install> can be true):
 
 =for stopwords sharedir
 
@@ -260,6 +291,10 @@ no prerequisites in build-requires
 
 =item *
 
+no L<files to be installed as executables|Dist::Zilla::Plugin::ExecDir> outside of the F<script> directory
+
+=item *
+
 no L<module sharedir|Dist::Zilla::Plugin::ModuleShareDirs> (a L<distribution sharedir|Dist::Zilla::Plugin::ShareDir> is okay)
 
 =item *
@@ -340,14 +375,6 @@ can see what the value would have been.
 
 =for Pod::Coverage BUILD metadata setup_installer
 
-=head1 SUPPORT
-
-=for stopwords irc
-
-Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-StaticInstall>
-(or L<bug-Dist-Zilla-Plugin-StaticInstall@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-StaticInstall@rt.cpan.org>).
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 SEE ALSO
 
 =over 4
@@ -356,13 +383,30 @@ I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
 L<CPAN::Meta::Spec>
 
+=item *
+
+L<CPAN::Static::Spec|https://github.com/Leont/cpan-static>.
+
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-StaticInstall>
+(or L<bug-Dist-Zilla-Plugin-StaticInstall@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-StaticInstall@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<irc://irc.perl.org/#distzilla>.
+
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
+
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2015 by Karen Etheridge.
 
